@@ -2,7 +2,7 @@ package Pipe::Tube::Csv;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use base 'Pipe::Tube';
 use Text::CSV_XS;
@@ -12,10 +12,12 @@ use Data::Dumper;
 sub init {
     my ($self, $attr) = @_;
     die "First paramater of csv should be HASH reference or nothing" if $attr and ref $attr ne 'HASH';
+	$attr ||= {};
 
     $self->logger("Receiving Csv definition: " . Dumper $attr);
 
     $self->{csv} = Text::CSV_XS->new($attr);
+
     return $self;
 }
 
@@ -40,13 +42,15 @@ Pipe::Tube::Csv - Csv processor tube in Pipe
 
 =head1 SYNPOSIS
 
-  my @resp = Pipe->for(@rows)->csv;
+  my @resp = Pipe->for(@rows)->csv->run;
 
-  my @resp = Pipe->cat("t/data/file1", "t/data/file2")->csv({ sep_char => "\t" });
+  my @resp = Pipe->cat("t/data/file1", "t/data/file2")
+            ->csv({ sep_char => "\t" })
+            ->run;
 
 =head1 DESCRIPTION
 
-The ->csv()  call can get a HASH reference parameter, the same parameter as 
+The ->csv()  call can get a HASH reference parameter, the same parameter as
 L<Text::CSV_XS> would get. We pass it directly to that module.
 
 Split up lines of csv file and return an array reference for each line.
@@ -57,13 +61,13 @@ TODO: use the first row as key names and on every other row return a hash of the
 
 =head1 AUTHOR
 
-Gabor Szabo <gabor@pti.co.il>
+Gabor Szabo <gabor@szabgab.com>
 
 =head1 COPYRIGHT
 
-Copyright 2006 by Gabor Szabo <gabor@pti.co.il>.
+Copyright 2006-2012 by Gabor Szabo <gabor@szabgab.com>.
 
-This program is free software; 
+This program is free software;
 you can redistribute it and/or modify it under the same terms as Perl itself.
 
 See http://www.perl.com/perl/misc/Artistic.html
